==> cscec5b-rmat-impl-3.0.1-20240119.060517-275-sources.jar: com/ejianc/business/rmat/vo/RentReportRestituteVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 项目租金报表
 *
 * @author generator
 *
 */
public class RentReportRestituteVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long reportId;
    private Long materialTypeId; // 物资材料分类Id
    private String materialTypeName; // 物资材料分类名称
    private Long materialId; // 材料id
    private String materialCode; // 材料编码
    private String materialName; // 材料名称
    private String materialSourceId; // 物资来源主键
    private String spec; // 规则/型号
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal sumNum; // 时点累计发生数量
    private BigDecimal rentMny; // 本期租金（无税）
    private BigDecimal rentTaxMny; // 本期租金（含税）
    private BigDecimal sumRentMny; // 累计租金（无税）
    private BigDecimal sumRentTaxMny; // 累计租金（含税）

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getRentTaxMny() {
        return rentTaxMny;
    }

    public void setRentTaxMny(BigDecimal rentTaxMny) {
        this.rentTaxMny = rentTaxMny;
    }

    public BigDecimal getSumRentMny() {
        return sumRentMny;
    }

    public void setSumRentMny(BigDecimal sumRentMny) {
        this.sumRentMny = sumRentMny;
    }

    public BigDecimal getSumRentTaxMny() {
        return sumRentTaxMny;
    }

    public void setSumRentTaxMny(BigDecimal sumRentTaxMny) {
        this.sumRentTaxMny = sumRentTaxMny;
    }
}

==> cscec5b-rmat-impl-3.0.1-20250120.095631-338-sources.jar: com/ejianc/business/rmat/vo/RentReportRestituteVO.java <==
package com.ejianc.business.rmat.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 项目租金报表
 *
 * @author generator
 *
 */
public class RentReportRestituteVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long reportId;
    private String contractId; // 合同主键
    private Long supplierId; // 设备供应商
    private Long materialTypeId; // 物资材料分类Id
    private String materialTypeName; // 物资材料分类名称
    private Long materialId; // 材料id
    private String materialCode; // 材料编码
    private String materialName; // 材料名称
    private String materialSourceId; // 物资来源主键
    private String spec; // 规则/型号
    private String rentUnitId; // 计租单位id
    private String rentUnitName; // 计租单位
    private BigDecimal sumNum; // 时点累计发生数量
    private BigDecimal rentMny; // 本期租金（无税）
    private BigDecimal rentTaxMny; // 本期租金（含税）
    private BigDecimal sumRentMny; // 累计租金（无税）
    private BigDecimal sumRentTaxMny; // 累计租金（含税）

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }

    public String getContractId() {
        return contractId;
    }

    public void setContractId(String contractId) {
        this.contractId = contractId;
    }

    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    public BigDecimal getRentMny() {
        return rentMny;
    }

    public void setRentMny(BigDecimal rentMny) {
        this.rentMny = rentMny;
    }

    public BigDecimal getRentTaxMny() {
        return rentTaxMny;
    }

    public void setRentTaxMny(BigDecimal rentTaxMny) {
        this.rentTaxMny = rentTaxMny;
    }

    public BigDecimal getSumRentMny() {
        return sumRentMny;
    }

    public void setSumRentMny(BigDecimal sumRentMny) {
        this.sumRentMny = sumRentMny;
    }

    public BigDecimal getSumRentTaxMny() {
        return sumRentTaxMny;
    }

    public void setSumRentTaxMny(BigDecimal sumRentTaxMny) {
        this.sumRentTaxMny = sumRentTaxMny;
    }
}
